@@ -661,7 +661,6 @@ int main(int argc, char **argv) {
     struct db_daemon_data d;
 #ifndef WIN32
     int ready_pipe[2] = {0, 0};
-    pid_t pid;
 #endif
     int ret;
 
@@ -696,7 +695,7 @@ int main(int argc, char **argv) {
             perror("pipe");
             exit(1);
         }
-        switch (pid = fork()) {
+        switch (fork()) {
             case -1:
                 perror("fork");
                 exit(1);
